''' (c) 2008 by the GunGame Coding Team

    Title: gg_winner_menu
    Version: 1.0.0
    Description: Custom addon.
    '''

# ==============================================================================
#   IMPORTS
# ==============================================================================
# EventScripts imports
import es
import gamethread
import popuplib

# GunGame imports
import gungamelib

# ==============================================================================
#   ADDON REGISTRATION
# ==============================================================================
# Register this addon with EventScripts
info = es.AddonInfo()
info.name     = 'A menu for the winner to select a gametype for the next map for GunGame 5'
info.version  = '1.0.0'
info.url      = 'http://forums.gungame5.com/viewtopic.php?f=17&t=337'
info.basename = 'gungame/custom_addons/gg_winner_menu'
info.author   = 'Sc0pE'

es.ServerVar('gg_winner_menu_ver', info.version).makepublic()

# ==============================================================================
#   GLOBALS
# ==============================================================================
menu_dict = {1:{}, 2:{}, 3:{}, 4:{}, 5:{}, 6:{}, 7:{}, 8:{}}
removeList = []

# For every gametype
for num in menu_dict:
    # Store information about each gametype
    title = gungamelib.getVariableValue('gg_winner_menu_%s_title' % num)
    # If they left the title of the gametype blank, do not add it as a gametype
    if title == '':
        removeList.append(num)
        continue
    menu_dict[num]['title'] = title
    menu_dict[num]['load'] = gungamelib.getVariableValue('gg_winner_menu_%s_items_load' % num)
    menu_dict[num]['unload'] = gungamelib.getVariableValue('gg_winner_menu_%s_items_unload' % num)

# Delete the blank gametypes after the original "for" loop is complete
for num in removeList:
    del menu_dict[num]

hide_gametypes = gungamelib.getVariableValue('gg_winner_menu_hide_gametypes')

# If the "hide previous gametypes" option is set high, make sure there are always at least two gametypes to choose from
if hide_gametypes > len(menu_dict) - 2:
    hide_gametypes = len(menu_dict) - 2
# Create the list that will handle storing previous gametypes
gametypes_list = []

menu = None

# ==============================================================================
#   GAME EVENTS
# ==============================================================================
def load():
    # Register this addon with GunGame
    gg_winner_menu = gungamelib.registerAddon('gg_winner_menu')
    gg_winner_menu.setDisplayName('GG Winner Menu')
    gg_winner_menu.loadTranslationFile()
    
    # Build the winner menu
    buildMenu()

def unload():
    global menu
    
    # Unload the last gametype selected
    es.server.queuecmd(menu_dict[gametypes_list[0]]['unload'])
    # Unregister this addon with GunGame
    gungamelib.unregisterAddon('gg_winner_menu')
    # Delete the menu
    menu.delete()

def gg_win(event_var):
    popuplib.find('gg_winner_menu').send(event_var['attacker'])

def es_map_start(event_var):
    # Load the selected gametype
    gamethread.delayed(0.5, es.server.queuecmd, (menu_dict[gametypes_list[0]]['load']))
    
    # Rebuild the menu
    buildMenu()

# ==============================================================================
#   HELPER FUNCTIONS
# ==============================================================================
def buildMenu():
    global menu
    
    # Start building the menu
    menu = popuplib.easymenu('gg_winner_menu', None, menuHandler)
    menu.settitle("Select next map's gametype:")
    # For every gametype
    for option in menu_dict:
        # If the option should be hidden due to the "hide previous gametypes" option, skip it
        if option in gametypes_list[:hide_gametypes]:
            continue
        # Add the menu option
        menu.addoption(option, menu_dict[option]['title'])
    menu.timeout('view', int(es.ServerVar('mp_chattime')))

def menuHandler(userid, choice, popupname):
    # Add the selected gametype to the gametypes list
    gametypes_list.insert(0, choice)
    # Clean up unnecessary gametypes from the list
    if len(gametypes_list) > hide_gametypes + 1:
        gametypes_list.remove(gametypes_list[-1])
    # If a previous gametype was selected, unload it
    if len(gametypes_list) > 1:
        es.server.queuecmd(menu_dict[gametypes_list[1]]['unload'])
    
    # Get the gungame player object
    gungameWinner = gungamelib.getPlayer(userid)
    # Send the message
    gamethread.delayed(1, gungamelib.saytext2,('gg_winner_menu', '#all', gungameWinner['index'], 'winnerSelected', {'winner':gungameWinner.name, 'type':menu_dict[choice]['title']}))